@@ -522,7 +522,7 @@ setup_accelerator (GtkAccelGroup *accel_group, GnomeUIInfo *uiinfo,
 					    uiinfo->ac_mods, accel_flags);
 }
 
-#ifndef	GTK_CHECK_VERSION
+#if 0
 GtkAccelGroup*
 gtk_menu_ensure_uline_accel_group (GtkMenu *menu)
 {
@@ -544,21 +544,6 @@ gtk_menu_ensure_uline_accel_group (GtkMenu *menu)
 
   return accel_group;
 }
-void
-gtk_item_factory_add_foreign (GtkWidget      *accel_widget,
-			      const gchar    *full_path,
-			      GtkAccelGroup  *accel_group,
-			      guint           keyval,
-			      GdkModifierType modifiers)
-{
-  if (accel_group)
-    gtk_widget_add_accelerator (accel_widget,
-				"activate",
-				accel_group,
-				keyval,
-				modifiers,
-				GTK_ACCEL_VISIBLE);
-}
 #endif
 
 /* Creates the accelerators for the underlined letter in a menu item's label. 
@@ -940,7 +925,7 @@ gnome_save_accels (gpointer data)
 	file_name = g_build_filename (gnome_user_accels_dir_get (),
 				      gnome_program_get_app_id (gnome_program_get()),
 				      NULL);
-	gtk_item_factory_dump_rc (file_name, NULL, TRUE);
+	gtk_accel_map_save (file_name);
 	g_free (file_name);
 
 	return TRUE;
@@ -1014,8 +999,8 @@ create_menu_item (GtkMenuShell       *menu_shell,
 		return;
 	}
 
-	if (!accel_group)
-		gtk_widget_lock_accelerators (uiinfo->widget);
+/*	if (!accel_group)
+		gtk_widget_lock_accelerators (uiinfo->widget); */
 
 	gtk_widget_show (uiinfo->widget);
 	gtk_menu_shell_insert (menu_shell, uiinfo->widget, pos);
@@ -1332,7 +1317,7 @@ create_help_entries (GtkMenuShell *menu_shell, GnomeUIInfo *uiinfo, gint pos)
 
 		gtk_container_add (GTK_CONTAINER (item), label);
 		setup_uline_accel (menu_shell, NULL, item, keyval);
-		gtk_widget_lock_accelerators (item);
+/*		gtk_widget_lock_accelerators (item); */
 
 		gtk_object_set_data_full (GTK_OBJECT (item), "docname",
 					  g_strdup (uiinfo->moreinfo),
@@ -1356,22 +1341,53 @@ create_help_entries (GtkMenuShell *menu_shell, GnomeUIInfo *uiinfo, gint pos)
 	return pos;
 }
 
+typedef struct
+{
+	GtkCallbackMarshal relay_func;
+	GtkDestroyNotify destroy_func;
+	gpointer user_data;
+} SavedData;
+
+static void
+ui_relay_callback (GtkObject *object,
+		   SavedData *saved_data)
+{
+	saved_data->relay_func (object, saved_data->user_data, 0, NULL);
+}
+
+static void
+ui_destroy_callback (SavedData *saved_data)
+{
+	if (saved_data->user_data)
+		saved_data->destroy_func (saved_data->user_data);
+	g_free (saved_data);
+}
+
 /* Performs signal connection as appropriate for interpreters or native bindings */
 static void
-do_ui_signal_connect (GnomeUIInfo *uiinfo, const char *signal_name, 
-		GnomeUIBuilderData *uibdata)
+do_ui_signal_connect (GnomeUIInfo        *uiinfo,
+		      const char         *signal_name, 
+		      GnomeUIBuilderData *uibdata)
 {
-	if (uibdata->is_interp)
+	if (uibdata->is_interp) {
+		SavedData *saved_data = g_new (SavedData, 1);
+		saved_data->relay_func = uibdata->relay_func;
+		saved_data->destroy_func = uibdata->destroy_func;
+		saved_data->user_data = uibdata->data ? uibdata->data : uiinfo->user_data;
+
 		gtk_signal_connect_full (GTK_OBJECT (uiinfo->widget), 
-				signal_name, NULL, uibdata->relay_func, 
-				uibdata->data ? 
-				uibdata->data : uiinfo->user_data,
-				uibdata->destroy_func, FALSE, FALSE);
+					 signal_name,
+					 GTK_SIGNAL_FUNC (ui_relay_callback),
+					 NULL,
+					 saved_data,
+					 (GtkDestroyNotify) ui_destroy_callback,
+					 FALSE, FALSE);
 	
-	else if (uiinfo->moreinfo)
+	} else if (uiinfo->moreinfo)
 		gtk_signal_connect (GTK_OBJECT (uiinfo->widget), 
-				signal_name, uiinfo->moreinfo, uibdata->data ? 
-				uibdata->data : uiinfo->user_data);
+				    signal_name,
+				    uiinfo->moreinfo,
+				    uibdata->data ? uibdata->data : uiinfo->user_data);
 }
 
 
